@@ -1,4 +1,5 @@
 """Exceptions for tmuxp."""
+
 import typing as t
 
 from libtmux._internal.query_list import ObjectDoesNotExist
@@ -111,7 +112,10 @@ class BeforeLoadScriptError(Exception):
     """
 
     def __init__(
-        self, returncode: int, cmd: str, output: t.Optional[str] = None
+        self,
+        returncode: int,
+        cmd: str,
+        output: t.Optional[str] = None,
     ) -> None:
         self.returncode = returncode
         self.cmd = cmd
